Struct TotalSize

pub struct TotalSize { /* private fields */ }
Represents the total space taken up by an instance of a variable, including heap allocations

Implementations

Source

impl TotalSize

pub const fn new( total_bytes: usize, excess_bytes: usize, shared_bytes: usize, distinct_allocations: usize, ) -> Self

Creates a new TotalSize

pub const fn zero() -> Self

Creates a TotalSize with a value of zero

pub const fn total(total: usize) -> Self

Sets total_bytes to total and all others to zero

pub const fn total_bytes(&self) -> usize

Returns the total bytes allocated

pub const fn excess_bytes(&self) -> usize

Returns the excess bytes allocated, the unused portions of allocated memory

pub const fn shared_bytes(&self) -> usize

Returns the number of shared bytes, bytes that are shared behind things like Arc or Rc

pub const fn distinct_allocations(&self) -> usize

Returns the number of distinct allocations

For example, a Box<u32> contains one distinct allocation while a Box<Box<u32>> contains two

pub const fn used_bytes(&self) -> usize

Return the total used bytes, calculated by total_bytes - excess_bytes