Struct size_of::TotalSize

source ·
pub struct TotalSize { /* private fields */ }
Represents the total space taken up by an instance of a variable, including heap allocations

Implementations

Creates a new TotalSize

Creates a TotalSize with a value of zero

Sets total_bytes to total and all others to zero

Returns the total bytes allocated

Returns the excess bytes allocated, the unused portions of allocated memory

Returns the number of shared bytes, bytes that are shared behind things like Arc or Rc

Returns the number of distinct allocations

For example, a Box<u32> contains one distinct allocation while a Box<Box<u32>> contains two

Return the total used bytes, calculated by total_bytes - excess_bytes