pub struct TotalSize { /* private fields */ }Expand description
Represents the total space taken up by an instance of a variable, including heap allocations
Implementations
sourceimpl TotalSize
impl TotalSize
sourcepub const fn new(
total_bytes: usize,
excess_bytes: usize,
shared_bytes: usize,
distinct_allocations: usize
) -> Self
pub const fn new(
total_bytes: usize,
excess_bytes: usize,
shared_bytes: usize,
distinct_allocations: usize
) -> Self
Creates a new TotalSize
sourcepub const fn total_bytes(&self) -> usize
pub const fn total_bytes(&self) -> usize
Returns the total bytes allocated
sourcepub const fn excess_bytes(&self) -> usize
pub const fn excess_bytes(&self) -> usize
Returns the excess bytes allocated, the unused portions of allocated memory
Returns the number of shared bytes, bytes that are shared behind things
like Arc or Rc
sourcepub const fn distinct_allocations(&self) -> usize
pub const fn distinct_allocations(&self) -> usize
Returns the number of distinct allocations
For example, a Box<u32> contains one distinct allocation while a
Box<Box<u32>> contains two
sourcepub const fn used_bytes(&self) -> usize
pub const fn used_bytes(&self) -> usize
Return the total used bytes, calculated by total_bytes - excess_bytes